==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/ColumnChooserDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ColumnChooserDescription } from "./ColumnChooserDescription";
/**
 * @hidden
 */
var ColumnChooserDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ColumnChooserDescriptionMetadata, _super);
    function ColumnChooserDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ColumnChooserDescriptionMetadata.b = function (a) {
        if (ColumnChooserDescriptionMetadata.a == null) {
            ColumnChooserDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ColumnChooserDescriptionMetadata.c(ColumnChooserDescriptionMetadata.a);
        }
        if (a.k(ColumnChooserDescriptionMetadata.a)) {
            return;
        }
        a.ab(ColumnChooserDescriptionMetadata.a);
    };
    ColumnChooserDescriptionMetadata.c = function (a) {
        a.item("TargetGridRef", "(w:TargetGrid,wf:TargetGrid)DataRef::object");
        a.item("Title", "String");
        a.item("TitleFontFamily", "(w:TitleFontFamily/FontFamilyTransform,xam:TitleFontFamily,wf:TitleFontFamily,web:titleStyle/FontFamilyTransform)String");
        a.item("TitleFontSize", "(w:TitleFontSize,xam:TitleFontSize,wf:TitleFontSize,web:titleStyle/FontSizeTransform)Number:double");
        a.item("TitleFontStyle", "(w:TitleFontStyle/FontStyleTransform,xam:TitleFontFamily/FontStyleTransform,wf:TitleFontFamily/FontStyleTransform,web:titleStyle/FontStyleTransform)String");
        a.item("TitleFontWeight", "(w:TitleFontWeight/FontWeightTransform,xam:TitleFontFamily/FontWeightTransform,wf:TitleFontFamily/FontWeightTransform,web:titleStyle/FontWeightTransform)String");
        a.item("TitleColor", "Brush");
        a.item("FilterPlaceholderText", "String");
        a.item("BaseTheme", "ExportedType:string:BaseControlTheme");
        a.item("BaseTheme@names", "Default;DenaliLight;MaterialLight;SlingshotLight;SlingshotDark;RevealLight;RevealDark");
        a.item("Density", "ExportedType:string:ControlDisplayDensity");
        a.item("Density@names", "Auto;Comfortable;Cosy;Compact");
        a.item("BackgroundColor", "Brush");
    };
    ColumnChooserDescriptionMetadata.d = function (a) {
        ColumnChooserDescriptionMetadata.b(a);
        a.ad("ColumnChooser", function () { return new ColumnChooserDescription(); });
        a.ac("ColumnChooser", ColumnChooserDescriptionMetadata.a);
    };
    ColumnChooserDescriptionMetadata.$t = markType(ColumnChooserDescriptionMetadata, 'ColumnChooserDescriptionMetadata');
    ColumnChooserDescriptionMetadata.a = null;
    return ColumnChooserDescriptionMetadata;
}(Base));
export { ColumnChooserDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/ColumnChooserDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ColumnChooserDescription } from "./ColumnChooserDescription";
/**
 * @hidden
 */
var ColumnChooserDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ColumnChooserDescriptionMetadata, _super);
    function ColumnChooserDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ColumnChooserDescriptionMetadata.b = function (a) {
        if (ColumnChooserDescriptionMetadata.a == null) {
            ColumnChooserDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ColumnChooserDescriptionMetadata.c(ColumnChooserDescriptionMetadata.a);
        }
        if (a.k(ColumnChooserDescriptionMetadata.a)) {
            return;
        }
        a.ac(ColumnChooserDescriptionMetadata.a);
    };
    ColumnChooserDescriptionMetadata.c = function (a) {
        a.item("TargetGridRef", "(w:TargetGrid,wf:TargetGrid)DataRef::object");
        a.item("Title", "String");
        a.item("TitleFontFamily", "(w:TitleFontFamily/FontFamilyTransform,xam:TitleFontFamily,wf:TitleFontFamily,web:titleStyle/FontFamilyTransform)String");
        a.item("TitleFontSize", "(w:TitleFontSize,xam:TitleFontSize,wf:TitleFontSize,web:titleStyle/FontSizeTransform)Number:double");
        a.item("TitleFontStyle", "(w:TitleFontStyle/FontStyleTransform,xam:TitleFontFamily/FontStyleTransform,wf:TitleFontFamily/FontStyleTransform,web:titleStyle/FontStyleTransform)String");
        a.item("TitleFontWeight", "(w:TitleFontWeight/FontWeightTransform,xam:TitleFontFamily/FontWeightTransform,wf:TitleFontFamily/FontWeightTransform,web:titleStyle/FontWeightTransform)String");
        a.item("TitleColor", "Brush");
        a.item("FilterPlaceholderText", "String");
        a.item("BaseTheme", "ExportedType:string:BaseControlTheme");
        a.item("BaseTheme@names", "Default;DenaliLight;MaterialLight;SlingshotLight;SlingshotDark;RevealLight;RevealDark");
        a.item("Density", "ExportedType:string:ControlDisplayDensity");
        a.item("Density@names", "Auto;Comfortable;Cosy;Compact");
        a.item("BackgroundColor", "Brush");
    };
    ColumnChooserDescriptionMetadata.d = function (a) {
        ColumnChooserDescriptionMetadata.b(a);
        a.ae("ColumnChooser", function () { return new ColumnChooserDescription(); });
        a.ad("ColumnChooser", ColumnChooserDescriptionMetadata.a);
    };
    ColumnChooserDescriptionMetadata.$t = markType(ColumnChooserDescriptionMetadata, 'ColumnChooserDescriptionMetadata');
    ColumnChooserDescriptionMetadata.a = null;
    return ColumnChooserDescriptionMetadata;
}(Base));
export { ColumnChooserDescriptionMetadata };
